@@ -15,6 +15,11 @@ class Jeu:
     """
 
     def __init__(self, roles=None):
+        if roles is None:
+            roles = ["tony", "pede", "loup-garou", "ble"]
+        self.reset_state(roles)
+
+    def reset_state(self, roles):
         if roles is None:
             self.roles = ["tony", "pede", "loup-garou", "ble"]
         else:
@@ -33,14 +38,17 @@ class Jeu:
     def setup(self, player_names, roles=None):
         """player_names is a dict: player_names[id] = display_name"""
         if roles is None:
-            self.__init__(roles=self.roles)
+            self.reset_state(self.roles)
         else:
-            self.__init__(roles=roles)
+            self.reset_state(roles)
+        if len(player_names) < len(self.roles):
+            return False
         for name in player_names:
             if name in self.joueurs.keys():
                 raise ValueError("Trying to add this player twice: {}".format(name))
             self.joueurs[name] = Joueur(name, player_names[name])
         self.set_roles()
+        return True
 
 
     def get_game_state(self):
@@ -98,8 +106,8 @@ class Jeu:
         """
         if self.lock_vote:
             return
-        assert voter in self.votes
-        assert voted in self.votes
+        if not voter in self.votes or not voted in self.votes:
+            return
         if self.votes[voter] == "":
             self.votes[voter] = voted
             self.n_votes += 1
